/*
	*
	* Copyright 2019 Britanicus <marcusbritanicus@gmail.com>
	*
	* This file is a part of DesQ project (https://gitlab.com/desq/)
	*

	*
	* This program is free software; you can redistribute it and/or modify
	* it under the terms of the GNU General Public License as published by
	* the Free Software Foundation; either version 3 of the License, or
	* (at your option) any later version.
	*

	*
	* This program is distributed in the hope that it will be useful,
	* but WITHOUT ANY WARRANTY; without even the implied warranty of
	* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	* GNU General Public License for more details.
	*

	*
	* You should have received a copy of the GNU General Public License
	* along with this program; if not, write to the Free Software
	* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
	* MA 02110-1301, USA.
	*
*/

// Local Headers
// #include "Global.hpp"
#include "DesQSplash.hpp"

// Wayland Headers
#include <desqwl/DesQWlGlobal.hpp>
#include <desqwl/Registry.hpp>
#include <desqwl/LayerShell.hpp>

int main( int argc, char **argv ) {

	qputenv( "QT_WAYLAND_USE_BYPASSWINDOWMANAGERHINT", QByteArrayLiteral( "1" ) );

	QCoreApplication::setAttribute( Qt::AA_EnableHighDpiScaling );

	QApplication app( argc, argv );

	/* strcmp(...) returns 0 when the two strings are equal */
	DesQSplash *splash = new DesQSplash( 0 );
	splash->show();

	QFontDatabase fdb;
	fdb.addApplicationFont( ":/fonts/Raleway-Regular.ttf" );

	wl_display *display = DesQWayland::getWlDisplay();
	if ( not display ) {
		qDebug() << "Unable to acquire wl_display from the compositor.";
		qDebug() << "Your experience will be severly limited.";

		return 0;
	}

	WaylandRegistry *registry = new WaylandRegistry( display );
	QObject::connect(
		registry, &WaylandRegistry::errorOccured, [=]( WaylandRegistry::ErrorType et ) {
			qDebug() << "Error caused on registry" << et;
			qDebug() << "Valiantly trying to continue...";
		}
	);
	registry->initialize();

	LayerSurface *cls = new LayerSurface( splash->windowHandle() );
	cls->setup( registry->lShell(), LayerShell::Bottom );
	cls->setAnchors( LayerSurface::Top | LayerSurface::Bottom | LayerSurface::Left | LayerSurface::Right );
	cls->setSurfaceSize( splash->size() );
	cls->setExclusiveZone( -1 );
	cls->setKeyboardInteractivity( LayerSurface::Exclusive );
	cls->apply();

	return app.exec();
};
